@@ -87,9 +87,13 @@ class Idler(soya.World, idler.Idler):
     self.camera = camera or soya.TravelingCamera(self)
     soya.set_root_widget(widget.Group())
     soya.root_widget.add(self.camera)
+
+    #def f():
+    #  print "!"
+    #self.camera.begin_round = f
     
     sound.init(self.camera)
-      
+    
     self.blackbands_group    = widget.Group() 
     self.no_blackbands_group = widget.Group()
     soya.root_widget.add(self.no_blackbands_group)
@@ -105,7 +109,8 @@ class Idler(soya.World, idler.Idler):
     self.waiting_until_ready = 0
     self.paused = None
     
-    soya.IDLER = self
+    soya.IDLER     = self
+    soya.MAIN_LOOP = self
     
     text = soya.widget.Label(None, "", 1)
     
@@ -409,7 +414,6 @@ class Level(level.Level, soya.World):
         
       if hasattr(self, "music_name"):
         if self.music_name: sound.play_music(self.music_name)
-        else: sound.preload_sound(self.preloaded_music_name, globdef.ASYNC_LOAD_MUSIC)
       else:
         sound.play_music("summum_of_the_light.ogg") # Default music
         
@@ -543,11 +547,11 @@ class FlameThrowerBonus(Bonus, soya.Bonus):
             self.parent.remove(self)
           break
         
-import math, soya.particle as particle
+import math, soya
 
-class LifeBonusParticle(particle.Particles):
+class LifeBonusParticle(soya.Particles):
   def __init__(self, parent = None, material = None, nb_particles = 30):
-    particle.Particles.__init__(self, parent, material, nb_particles, 1)
+    soya.Particles.__init__(self, parent, material, nb_particles, 1)
     self.set_colors((0.2, 0.0, 0.1, 1.0), (1.0, 0.2, 0.6, 1.0), (0.1, 0.0, 0.0, 1.0))
     self.set_sizes ((1.0, 1.0))
     self.life = 10
@@ -562,7 +566,7 @@ class LifeBonusParticle(particle.Particles):
     self.set_particle(index, 0.5 + random.random(), sx * l, sy * l, sz * l, 0.0, 0.03, 0.0)
     
   def aaabegin_round(self):
-    particle.Particles.begin_round(self)
+    soya.Particles.begin_round(self)
     if   self.life >  0: self.life -= 1
     elif self.life == 0:
       self.auto_generate_particle = 0
