@@ -489,8 +489,8 @@ def make_world():
     light._matrix = (0.63844746351242065, 0.0, 0.76966547966003418, 0.0, 0.33340060710906982, -0.90130943059921265, -0.27656009793281555, 0.0, 0.6937066912651062, 0.43317598104476929, -0.57543867826461792, 0.0, 0.0, 5.0, 0.0, 1.0, 1.0, 1.0, 1.0)
 
     # add labo smoke
-    import soya.particle
-    smoke = soya.particle.Smoke(w)
+    import soya
+    smoke = soya.Smoke(w)
     smoke.nb_max = 20
     smoke.auto_generate_particle = 1
     smoke.set_xyz(121.9, 4.5, 131.5)
