@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Slune
 # Copyright (C) 2002-2003 Jean-Baptiste LAMY
 #
@@ -50,6 +52,8 @@ class VideoSequence:
           if getattr(character, "name", "") == name:
             character.controler.animate(self(**{name : character}))
       elif character:
+        if isinstance(character, tuple):
+          character = character[0]
         character.controler.animate(self(**{name : character}))
         
 def add_perso(name, vehicle = 1, clazz = NonPlayerCharacter, level = None, **kargs):
@@ -311,7 +315,7 @@ class Mission1Intro(VideoSequence):
     yield Pause()
     
     if   gnu:
-      if globdef.HAS_OGG: sound.play("phone.ogg")
+      sound.play("phone.ogg")
       IDLER.clear_message(); IDLER.message(_("__scenar1-intro-1__"))
       
     elif tux:
@@ -1390,7 +1394,7 @@ class Mission6Intro(VideoSequence):
     yield Pause()
     
     if   gnu:
-      if globdef.HAS_OGG: sound.play("phone.ogg")
+      sound.play("phone.ogg")
       IDLER.clear_message(); IDLER.message(_("__scenar6-intro-3__"))
       
     yield Pause(); yield Fade()
@@ -1514,10 +1518,10 @@ class Mission7Intro(VideoSequence):
     if   tux and tux.player.active: # Do this once
       IDLER.clear_message()
       
-      tux.level.python = python = soya.World(tux.level, shape = soya.Shape.get("vehicle3"))
+      tux.level.python = python = soya.World(tux.level, model = soya.Shape.get("vehicle3"))
       python.set_xyz(34.326007843, 0.888233947754, 12.4514389038)
       python.rotate_lateral(180.0)
-      soya.Volume(python, shape = soya.Shape.get("python1")).set_xyz(0.0, 0.2, 0.35)
+      soya.Volume(python, model = soya.Shape.get("python1")).set_xyz(0.0, 0.2, 0.35)
       
 class Mission7AddEnemy(VideoSequence):
   def __init__(self, character, x, y, z, make_fall = None):
@@ -1733,7 +1737,7 @@ class Mission8Intro(VideoSequence):
       IDLER.clear_message()
       
       python_vehicle = soya.World(tux.level)
-      python_vehicle.shape = soya.Shape.get("vehicle3")
+      python_vehicle.model = soya.Shape.get("vehicle3")
       python_vehicle.set_xyz(111.893669128, 1.8, 136.298706055)
       python_vehicle.rotate_lateral(180.0)
       python = soya.Volume(python_vehicle, soya.Shape.get("python1"))
